==> aws-java-sdk-importexport-1.10.25-sources.jar: com/amazonaws/services/importexport/model/transform/ListJobsResultStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.importexport.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.importexport.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * ListJobsResult StAX Unmarshaller
 */
public class ListJobsResultStaxUnmarshaller implements
        Unmarshaller<ListJobsResult, StaxUnmarshallerContext> {

    public ListJobsResult unmarshall(StaxUnmarshallerContext context)
            throws Exception {
        ListJobsResult listJobsResult = new ListJobsResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return listJobsResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

                if (context.testExpression("Jobs/member", targetDepth)) {
                    listJobsResult.getJobs().add(
                            JobStaxUnmarshaller.getInstance().unmarshall(
                                    context));
                    continue;
                }

                if (context.testExpression("IsTruncated", targetDepth)) {
                    listJobsResult.setIsTruncated(BooleanStaxUnmarshaller
                            .getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return listJobsResult;
                }
            }
        }
    }

    private static ListJobsResultStaxUnmarshaller instance;

    public static ListJobsResultStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new ListJobsResultStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-importexport-1.11.29-sources.jar: com/amazonaws/services/importexport/model/transform/ListJobsResultStaxUnmarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.importexport.model.transform;

import java.util.Map;
import java.util.HashMap;
import java.util.ArrayList;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.importexport.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * ListJobsResult StAX Unmarshaller
 */
public class ListJobsResultStaxUnmarshaller implements
        Unmarshaller<ListJobsResult, StaxUnmarshallerContext> {

    public ListJobsResult unmarshall(StaxUnmarshallerContext context)
            throws Exception {
        ListJobsResult listJobsResult = new ListJobsResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return listJobsResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

                if (context.testExpression("Jobs/member", targetDepth)) {
                    listJobsResult.withJobs(JobStaxUnmarshaller.getInstance()
                            .unmarshall(context));
                    continue;
                }

                if (context.testExpression("IsTruncated", targetDepth)) {
                    listJobsResult.setIsTruncated(BooleanStaxUnmarshaller
                            .getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return listJobsResult;
                }
            }
        }
    }

    private static ListJobsResultStaxUnmarshaller instance;

    public static ListJobsResultStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new ListJobsResultStaxUnmarshaller();
        return instance;
    }
}
